debug = True
from splitapiclient.resources.traffic_type import TrafficType
from splitapiclient.resources.environment import Environment
from splitapiclient.resources.split import Split
from splitapiclient.resources.segment import Segment
from splitapiclient.resources.segment_definition import SegmentDefinition
from splitapiclient.resources.workspace import Workspace
from splitapiclient.resources.identity import Identity
from splitapiclient.resources.attribute import Attribute
from splitapiclient.resources.split_definition import SplitDefinition
from splitapiclient.resources.change_request import ChangeRequest
from splitapiclient.resources.user import User
from splitapiclient.resources.group import Group
from splitapiclient.resources.apikey import APIKey
from splitapiclient.resources.restriction import Restriction
from splitapiclient.resources.flag_set import FlagSet
from splitapiclient.resources.large_segment import LargeSegment
from splitapiclient.resources.large_segment_definition import LargeSegmentDefinition
from splitapiclient.resources.rule_based_segment import RuleBasedSegment
from splitapiclient.resources.rule_based_segment_definition import RuleBasedSegmentDefinition